import React, { useState, useCallback, useMemo, useEffect, useRef } from 'react';
import { Link, useLocation } from 'react-router-dom';
import { 
  Shield, 
  Phone, 
  Mail, 
  Menu, 
  X,
  ChevronDown,
  ChevronRight,
  MapPin,
  Star,
  MessageCircle,
  ArrowUp,
  Zap
} from 'lucide-react';

interface LayoutProps {
  children: React.ReactNode;
}

export default function Layout({ children }: LayoutProps) {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [isServicesOpen, setIsServicesOpen] = useState(false);
  const [isServiceAreasOpen, setIsServiceAreasOpen] = useState(false);
  const [mobileServicesOpen, setMobileServicesOpen] = useState(false);
  const [mobileServiceAreasOpen, setMobileServiceAreasOpen] = useState(false);
  const [isScrolled, setIsScrolled] = useState(false);
  const [showScrollTop, setShowScrollTop] = useState(false);
  const [focusedDropdown, setFocusedDropdown] = useState<string | null>(null);
  const [showChatWidget, setShowChatWidget] = useState(false);
  
  const location = useLocation();
  const servicesTimeoutRef = useRef<NodeJS.Timeout>();
  const serviceAreasTimeoutRef = useRef<NodeJS.Timeout>();
  const navRef = useRef<HTMLElement>(null);

  // Enhanced scroll handling with smooth animations
  useEffect(() => {
    const handleScroll = () => {
      const scrollY = window.scrollY;
      setIsScrolled(scrollY > 20);
      setShowScrollTop(scrollY > 400);
    };

    window.addEventListener('scroll', handleScroll, { passive: true });
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  // Auto-show chat widget after user engagement
  useEffect(() => {
    const timer = setTimeout(() => {
      setShowChatWidget(true);
    }, 30000); // Show after 30 seconds

    return () => clearTimeout(timer);
  }, []);

  // Close mobile menu on route change with smooth transition
  useEffect(() => {
    setIsMenuOpen(false);
    setMobileServicesOpen(false);
    setMobileServiceAreasOpen(false);
  }, [location.pathname]);

  // Enhanced keyboard navigation
  useEffect(() => {
    const handleEscape = (e: KeyboardEvent) => {
      if (e.key === 'Escape') {
        setIsMenuOpen(false);
        setIsServicesOpen(false);
        setIsServiceAreasOpen(false);
        setFocusedDropdown(null);
      }
    };

    document.addEventListener('keydown', handleEscape);
    return () => document.removeEventListener('keydown', handleEscape);
  }, []);

  // Smart click outside handling
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (navRef.current && !navRef.current.contains(event.target as Node)) {
        setIsServicesOpen(false);
        setIsServiceAreasOpen(false);
        setFocusedDropdown(null);
      }
    };

    document.addEventListener('mousedown', handleClickOutside);
    return () => document.removeEventListener('mousedown', handleClickOutside);
  }, []);

  const isActive = useCallback((path: string) => {
    return location.pathname === path;
  }, [location.pathname]);

  const isServicesActive = useCallback(() => {
    return location.pathname.startsWith('/services/');
  }, [location.pathname]);

  const isServiceAreasActive = useCallback(() => {
    return location.pathname.startsWith('/miami-it-services/');
  }, [location.pathname]);

  const services = useMemo(() => [
    { 
      name: 'Cybersecurity Services', 
      path: '/services/cybersecurity-services', 
      description: 'Advanced threat protection & security',
      icon: '🛡️',
      popular: true
    },
    { 
      name: 'Cloud Solutions', 
      path: '/services/cloud-solutions', 
      description: 'Scalable cloud infrastructure',
      icon: '☁️',
      popular: true
    },
    { 
      name: 'Network Management', 
      path: '/services/network-management', 
      description: 'Reliable network solutions',
      icon: '🌐',
      popular: false
    },
    { 
      name: '24/7 IT Support', 
      path: '/services/it-support', 
      description: 'Round-the-clock technical support',
      icon: '🎧',
      popular: true
    },
    { 
      name: 'Data Backup & Recovery', 
      path: '/services/data-backup-recovery', 
      description: 'Secure data protection',
      icon: '💾',
      popular: false
    },
    { 
      name: 'IT Consulting', 
      path: '/services/it-consulting', 
      description: 'Strategic technology planning',
      icon: '💡',
      popular: false
    },
    { 
      name: 'Microsoft 365 Services', 
      path: '/services/microsoft-365-services', 
      description: 'Complete Office 365 solutions',
      icon: '📊',
      popular: true
    }
  ], []);

  const serviceAreas = useMemo(() => [
    { name: 'Downtown Miami', path: '/miami-it-services/downtown-miami-it-support', description: 'Financial & business district', popular: true },
    { name: 'Brickell', path: '/miami-it-services/brickell-it-services', description: 'Banking & finance hub', popular: true },
    { name: 'Coral Gables', path: '/miami-it-services/coral-gables-it-support', description: 'Professional services area', popular: true },
    { name: 'Coconut Grove', path: '/miami-it-services/coconut-grove-it-services', description: 'Arts & creative district', popular: false },
    { name: 'South Beach', path: '/miami-it-services/south-beach-it-support', description: 'Hospitality & entertainment', popular: true },
    { name: 'Aventura', path: '/miami-it-services/aventura-it-services', description: 'Luxury retail & business', popular: false },
    { name: 'Doral', path: '/miami-it-services/doral-it-support', description: 'International business hub', popular: false },
    { name: 'Hialeah', path: '/miami-it-services/hialeah-it-services', description: 'Industrial & manufacturing', popular: false },
    { name: 'Homestead', path: '/miami-it-services/homestead-it-support', description: 'Agricultural & logistics', popular: false },
    { name: 'Kendall', path: '/miami-it-services/kendall-it-services', description: 'Suburban business community', popular: false },
    { name: 'Miami Lakes', path: '/miami-it-services/miami-lakes-it-support', description: 'Family business focus', popular: false },
    { name: 'Wynwood', path: '/miami-it-services/wynwood-it-services', description: 'Creative & startup district', popular: false },
    { name: 'All Miami-Dade', path: '/miami-it-services/miami-dade-county-it-services', description: 'County-wide coverage', popular: true }
  ], []);

  // Enhanced hover handlers with better timing
  const handleServicesMouseEnter = useCallback(() => {
    if (servicesTimeoutRef.current) {
      clearTimeout(servicesTimeoutRef.current);
    }
    setIsServicesOpen(true);
    setIsServiceAreasOpen(false);
  }, []);

  const handleServicesMouseLeave = useCallback(() => {
    servicesTimeoutRef.current = setTimeout(() => {
      setIsServicesOpen(false);
    }, 200);
  }, []);

  const handleServiceAreasMouseEnter = useCallback(() => {
    if (serviceAreasTimeoutRef.current) {
      clearTimeout(serviceAreasTimeoutRef.current);
    }
    setIsServiceAreasOpen(true);
    setIsServicesOpen(false);
  }, []);

  const handleServiceAreasMouseLeave = useCallback(() => {
    serviceAreasTimeoutRef.current = setTimeout(() => {
      setIsServiceAreasOpen(false);
    }, 200);
  }, []);

  // Enhanced keyboard navigation
  const handleServicesKeyDown = useCallback((e: React.KeyboardEvent) => {
    if (e.key === 'Enter' || e.key === ' ') {
      e.preventDefault();
      setIsServicesOpen(!isServicesOpen);
      setIsServiceAreasOpen(false);
      setFocusedDropdown(isServicesOpen ? null : 'services');
    } else if (e.key === 'ArrowDown' && isServicesOpen) {
      e.preventDefault();
      const firstItem = document.querySelector('[data-dropdown="services"] a') as HTMLElement;
      firstItem?.focus();
    }
  }, [isServicesOpen]);

  const handleServiceAreasKeyDown = useCallback((e: React.KeyboardEvent) => {
    if (e.key === 'Enter' || e.key === ' ') {
      e.preventDefault();
      setIsServiceAreasOpen(!isServiceAreasOpen);
      setIsServicesOpen(false);
      setFocusedDropdown(isServiceAreasOpen ? null : 'service-areas');
    } else if (e.key === 'ArrowDown' && isServiceAreasOpen) {
      e.preventDefault();
      const firstItem = document.querySelector('[data-dropdown="service-areas"] a') as HTMLElement;
      firstItem?.focus();
    }
  }, [isServiceAreasOpen]);

  const closeMobileMenu = useCallback(() => {
    setIsMenuOpen(false);
    setMobileServicesOpen(false);
    setMobileServiceAreasOpen(false);
  }, []);

  const toggleMobileServices = useCallback(() => {
    setMobileServicesOpen(prev => !prev);
    setMobileServiceAreasOpen(false);
  }, []);

  const toggleMobileServiceAreas = useCallback(() => {
    setMobileServiceAreasOpen(prev => !prev);
    setMobileServicesOpen(false);
  }, []);

  // Smooth scroll to top
  const scrollToTop = useCallback(() => {
    window.scrollTo({
      top: 0,
      behavior: 'smooth'
    });
  }, []);

  return (
    <div className="min-h-screen bg-white">
      {/* Enhanced Top Contact Bar with better visibility */}
      <div className="bg-gradient-to-r from-blue-600 to-blue-700 text-white py-3 relative z-50 shadow-sm">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center text-sm">
            <div className="flex items-center space-x-6">
              <div className="flex items-center group">
                <Phone className="h-4 w-4 mr-2 group-hover:animate-pulse" />
                <a 
                  href="tel:3055550123" 
                  className="font-semibold hover:text-blue-200 transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-300 focus:ring-offset-2 focus:ring-offset-blue-600 rounded px-2 py-1 hover:bg-blue-500/20"
                  aria-label="Call us at (305) 555-0123 for immediate IT support"
                >
                  (305) 555-0123
                </a>
                <span className="ml-2 text-xs bg-green-500 text-white px-2 py-0.5 rounded-full animate-pulse">
                  24/7
                </span>
              </div>
              <div className="hidden sm:flex items-center group">
                <Mail className="h-4 w-4 mr-2 group-hover:animate-bounce" />
                <a 
                  href="mailto:info@manageditservicesmiamifl.com" 
                  className="hover:text-blue-200 transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-300 focus:ring-offset-2 focus:ring-offset-blue-600 rounded px-2 py-1 hover:bg-blue-500/20"
                  aria-label="Email us for IT consultation"
                >
                  info@manageditservicesmiamifl.com
                </a>
              </div>
            </div>
            <div className="hidden md:flex items-center space-x-4 text-xs">
              <div className="flex items-center bg-blue-500/20 px-3 py-1 rounded-full">
                <Zap className="h-3 w-3 mr-1 text-yellow-300" />
                <span>15min Response Time</span>
              </div>
              <div className="flex items-center bg-blue-500/20 px-3 py-1 rounded-full">
                <Star className="h-3 w-3 mr-1 text-yellow-300" />
                <span>500+ Happy Clients</span>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Enhanced Main Navigation with better UX */}
      <nav 
        ref={navRef}
        className={`bg-white shadow-lg fixed w-full z-40 transition-all duration-500 ease-out ${
          isScrolled ? 'top-0 shadow-2xl backdrop-blur-sm bg-white/95' : 'top-12'
        }`}
        role="navigation"
        aria-label="Main navigation"
      >
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16">
            {/* Enhanced Logo with better branding */}
            <div className="flex items-center flex-shrink-0">
              <Link 
                to="/" 
                className="flex items-center group focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 rounded-lg p-2 transition-all duration-300 hover:bg-blue-50"
                aria-label="Managed IT Services Miami - Home"
              >
                <div className="relative">
                  <Shield className="h-8 w-8 text-blue-600 mr-3 group-hover:text-blue-700 transition-all duration-300 group-hover:scale-110" />
                  <div className="absolute -top-1 -right-1 w-3 h-3 bg-green-500 rounded-full animate-pulse"></div>
                </div>
                <div className="flex flex-col">
                  <span className="font-bold text-lg text-gray-900 group-hover:text-blue-600 transition-colors leading-tight">
                    Managed IT Services
                  </span>
                  <span className="text-sm text-blue-600 font-medium leading-tight">Miami • Since 2008</span>
                </div>
              </Link>
            </div>
            
            {/* Enhanced Desktop Menu */}
            <div className="hidden lg:block">
              <div className="ml-10 flex items-center space-x-1">
                <Link 
                  to="/" 
                  className={`nav-link px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105 ${
                    isActive('/') 
                      ? 'text-blue-600 bg-blue-50 shadow-md border border-blue-200' 
                      : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm'
                  }`}
                  aria-current={isActive('/') ? 'page' : undefined}
                >
                  Home
                </Link>
                
                {/* Enhanced Services Dropdown */}
                <div className="relative">
                  <button
                    onMouseEnter={handleServicesMouseEnter}
                    onMouseLeave={handleServicesMouseLeave}
                    onKeyDown={handleServicesKeyDown}
                    onFocus={() => setFocusedDropdown('services')}
                    className={`nav-link px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 flex items-center focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105 ${
                      isServicesActive() || isServicesOpen
                        ? 'text-blue-600 bg-blue-50 shadow-md border border-blue-200' 
                        : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm'
                    }`}
                    aria-expanded={isServicesOpen}
                    aria-haspopup="true"
                    aria-label="Services menu"
                  >
                    Services
                    <ChevronDown className={`ml-1 h-4 w-4 transition-all duration-300 ${
                      isServicesOpen ? 'rotate-180 text-blue-600' : ''
                    }`} />
                  </button>
                  
                  {/* Enhanced Services Dropdown Menu */}
                  {isServicesOpen && (
                    <div 
                      className="absolute top-full left-0 mt-3 w-96 bg-white rounded-2xl shadow-2xl border border-gray-100 py-4 z-50 animate-fade-in-up backdrop-blur-sm"
                      onMouseEnter={handleServicesMouseEnter}
                      onMouseLeave={handleServicesMouseLeave}
                      data-dropdown="services"
                      role="menu"
                      aria-label="Services submenu"
                    >
                      <div className="px-6 py-3 border-b border-gray-100 bg-gradient-to-r from-blue-50 to-indigo-50 rounded-t-2xl">
                        <h3 className="text-sm font-bold text-gray-900 flex items-center">
                          <Zap className="h-4 w-4 mr-2 text-blue-600" />
                          Our IT Services
                        </h3>
                        <p className="text-xs text-gray-600 mt-1">Comprehensive technology solutions for Miami businesses</p>
                      </div>
                      <div className="py-2 max-h-80 overflow-y-auto">
                        {services.map((service, index) => (
                          <Link
                            key={index}
                            to={service.path}
                            className="flex items-start px-6 py-3 text-sm hover:bg-gradient-to-r hover:from-blue-50 hover:to-indigo-50 transition-all duration-300 focus:outline-none focus:bg-blue-50 group border-l-4 border-transparent hover:border-blue-500"
                            role="menuitem"
                            tabIndex={isServicesOpen ? 0 : -1}
                          >
                            <span className="text-xl mr-4 group-hover:scale-125 transition-transform duration-300">
                              {service.icon}
                            </span>
                            <div className="flex-1">
                              <div className="flex items-center">
                                <span className="font-semibold text-gray-900 group-hover:text-blue-600 transition-colors">
                                  {service.name}
                                </span>
                                {service.popular && (
                                  <span className="ml-2 text-xs bg-green-100 text-green-700 px-2 py-0.5 rounded-full font-medium">
                                    Popular
                                  </span>
                                )}
                              </div>
                              <div className="text-xs text-gray-500 mt-1 leading-relaxed">
                                {service.description}
                              </div>
                            </div>
                          </Link>
                        ))}
                      </div>
                      <div className="px-6 py-4 border-t border-gray-100 bg-gradient-to-r from-green-50 to-blue-50 rounded-b-2xl">
                        <div className="flex items-center justify-between">
                          <div>
                            <p className="text-xs text-gray-600 font-medium">Need immediate help?</p>
                            <a 
                              href="tel:3055550123"
                              className="text-sm text-blue-600 hover:text-blue-700 font-bold flex items-center group"
                            >
                              Call (305) 555-0123
                              <Phone className="h-3 w-3 ml-1 group-hover:animate-pulse" />
                            </a>
                          </div>
                          <div className="text-xs text-green-600 font-semibold bg-green-100 px-3 py-1 rounded-full">
                            24/7 Support
                          </div>
                        </div>
                      </div>
                    </div>
                  )}
                </div>

                {/* Enhanced Service Areas Dropdown */}
                <div className="relative">
                  <button
                    onMouseEnter={handleServiceAreasMouseEnter}
                    onMouseLeave={handleServiceAreasMouseLeave}
                    onKeyDown={handleServiceAreasKeyDown}
                    onFocus={() => setFocusedDropdown('service-areas')}
                    className={`nav-link px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 flex items-center focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105 ${
                      isServiceAreasActive() || isServiceAreasOpen
                        ? 'text-blue-600 bg-blue-50 shadow-md border border-blue-200' 
                        : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm'
                    }`}
                    aria-expanded={isServiceAreasOpen}
                    aria-haspopup="true"
                    aria-label="Service areas menu"
                  >
                    Areas
                    <ChevronDown className={`ml-1 h-4 w-4 transition-all duration-300 ${
                      isServiceAreasOpen ? 'rotate-180 text-blue-600' : ''
                    }`} />
                  </button>
                  
                  {/* Enhanced Service Areas Dropdown Menu */}
                  {isServiceAreasOpen && (
                    <div 
                      className="absolute top-full left-0 mt-3 w-80 bg-white rounded-2xl shadow-2xl border border-gray-100 py-4 z-50 max-h-96 overflow-y-auto animate-fade-in-up backdrop-blur-sm"
                      onMouseEnter={handleServiceAreasMouseEnter}
                      onMouseLeave={handleServiceAreasMouseLeave}
                      data-dropdown="service-areas"
                      role="menu"
                      aria-label="Service areas submenu"
                    >
                      <div className="px-6 py-3 border-b border-gray-100 bg-gradient-to-r from-green-50 to-blue-50 rounded-t-2xl">
                        <h3 className="text-sm font-bold text-gray-900 flex items-center">
                          <MapPin className="h-4 w-4 mr-2 text-green-600" />
                          Service Areas
                        </h3>
                        <p className="text-xs text-gray-600 mt-1">We serve all of Miami-Dade County</p>
                      </div>
                      <div className="py-2">
                        {serviceAreas.map((area, index) => (
                          <Link
                            key={index}
                            to={area.path}
                            className="flex items-start px-6 py-2.5 text-sm hover:bg-gradient-to-r hover:from-green-50 hover:to-blue-50 transition-all duration-300 focus:outline-none focus:bg-blue-50 group border-l-4 border-transparent hover:border-green-500"
                            role="menuitem"
                            tabIndex={isServiceAreasOpen ? 0 : -1}
                          >
                            <MapPin className="h-4 w-4 text-green-500 mr-3 mt-0.5 flex-shrink-0 group-hover:text-green-600 transition-colors group-hover:scale-110" />
                            <div className="flex-1">
                              <div className="flex items-center">
                                <span className="font-semibold text-gray-900 group-hover:text-green-600 transition-colors">
                                  {area.name}
                                </span>
                                {area.popular && (
                                  <span className="ml-2 text-xs bg-blue-100 text-blue-700 px-2 py-0.5 rounded-full font-medium">
                                    Popular
                                  </span>
                                )}
                              </div>
                              <div className="text-xs text-gray-500 leading-relaxed">
                                {area.description}
                              </div>
                            </div>
                          </Link>
                        ))}
                      </div>
                    </div>
                  )}
                </div>
                
                <Link 
                  to="/project-gallery" 
                  className={`nav-link px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105 ${
                    isActive('/project-gallery') 
                      ? 'text-blue-600 bg-blue-50 shadow-md border border-blue-200' 
                      : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm'
                  }`}
                  aria-current={isActive('/project-gallery') ? 'page' : undefined}
                >
                  Projects
                </Link>
                <Link 
                  to="/blog" 
                  className={`nav-link px-4 py-2.5 rounded-lg text-sm font-medium transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105 ${
                    isActive('/blog') 
                      ? 'text-blue-600 bg-blue-50 shadow-md border border-blue-200' 
                      : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm'
                  }`}
                  aria-current={isActive('/blog') ? 'page' : undefined}
                >
                  Blog
                </Link>
                <a 
                  href="#about" 
                  className="nav-link px-4 py-2.5 rounded-lg text-sm font-medium text-gray-700 hover:text-blue-600 hover:bg-blue-50 hover:shadow-sm transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 hover:scale-105"
                >
                  About
                </a>
                <a 
                  href="#contact" 
                  className="bg-gradient-to-r from-blue-600 to-blue-700 text-white px-6 py-2.5 rounded-lg hover:from-blue-700 hover:to-blue-800 transition-all duration-300 font-medium text-sm shadow-lg hover:shadow-xl transform hover:scale-105 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 relative overflow-hidden group"
                >
                  <span className="relative z-10">Contact</span>
                  <div className="absolute inset-0 bg-gradient-to-r from-blue-700 to-blue-800 transform scale-x-0 group-hover:scale-x-100 transition-transform duration-300 origin-left"></div>
                </a>
              </div>
            </div>

            {/* Enhanced Mobile menu button */}
            <div className="lg:hidden">
              <button 
                onClick={() => setIsMenuOpen(!isMenuOpen)} 
                className="text-gray-700 hover:text-blue-600 p-3 rounded-lg hover:bg-blue-50 transition-all duration-300 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 relative"
                aria-expanded={isMenuOpen}
                aria-label={isMenuOpen ? 'Close menu' : 'Open menu'}
              >
                <div className="relative w-6 h-6">
                  <span className={`absolute block w-6 h-0.5 bg-current transform transition-all duration-300 ${isMenuOpen ? 'rotate-45 top-3' : 'top-1'}`}></span>
                  <span className={`absolute block w-6 h-0.5 bg-current transform transition-all duration-300 ${isMenuOpen ? 'opacity-0' : 'top-3'}`}></span>
                  <span className={`absolute block w-6 h-0.5 bg-current transform transition-all duration-300 ${isMenuOpen ? '-rotate-45 top-3' : 'top-5'}`}></span>
                </div>
              </button>
            </div>
          </div>
        </div>

        {/* Enhanced Mobile Menu */}
        {isMenuOpen && (
          <div className="lg:hidden bg-white border-t shadow-2xl animate-fade-in-down backdrop-blur-sm bg-white/95">
            <div className="px-4 pt-4 pb-6 space-y-2 max-h-96 overflow-y-auto">
              <Link 
                to="/" 
                className={`mobile-nav-item block px-4 py-3 rounded-lg font-medium transition-all duration-300 ${
                  isActive('/') 
                    ? 'text-blue-600 bg-gradient-to-r from-blue-50 to-indigo-50 border-l-4 border-blue-600 shadow-sm' 
                    : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50'
                }`}
                onClick={closeMobileMenu}
                aria-current={isActive('/') ? 'page' : undefined}
              >
                🏠 Home
              </Link>
              
              {/* Enhanced Mobile Services Menu */}
              <div className="space-y-1">
                <button
                  onClick={toggleMobileServices}
                  className={`mobile-nav-item flex items-center justify-between w-full px-4 py-3 rounded-lg font-medium transition-all duration-300 ${
                    isServicesActive() || mobileServicesOpen
                      ? 'text-blue-600 bg-gradient-to-r from-blue-50 to-indigo-50 shadow-sm' 
                      : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50'
                  }`}
                  aria-expanded={mobileServicesOpen}
                  aria-label="Services menu"
                >
                  <span className="flex items-center">
                    🛠️ Services
                    {mobileServicesOpen && <span className="ml-2 text-xs bg-blue-100 text-blue-700 px-2 py-0.5 rounded-full">7 Services</span>}
                  </span>
                  <ChevronRight className={`h-4 w-4 transition-transform duration-300 ${
                    mobileServicesOpen ? 'rotate-90' : ''
                  }`} />
                </button>
                {mobileServicesOpen && (
                  <div className="pl-4 space-y-1 animate-fade-in-up">
                    {services.map((service, index) => (
                      <Link
                        key={index}
                        to={service.path}
                        className="flex items-center px-4 py-3 text-sm text-gray-600 hover:text-blue-600 hover:bg-gradient-to-r hover:from-blue-50 hover:to-indigo-50 rounded-lg transition-all duration-300 group"
                        onClick={closeMobileMenu}
                      >
                        <span className="text-base mr-3 group-hover:scale-110 transition-transform">{service.icon}</span>
                        <div className="flex-1">
                          <div className="flex items-center">
                            <span className="font-medium">{service.name}</span>
                            {service.popular && (
                              <span className="ml-2 text-xs bg-green-100 text-green-700 px-2 py-0.5 rounded-full">
                                Popular
                              </span>
                            )}
                          </div>
                          <div className="text-xs text-gray-500">{service.description}</div>
                        </div>
                      </Link>
                    ))}
                  </div>
                )}
              </div>

              {/* Enhanced Mobile Service Areas Menu */}
              <div className="space-y-1">
                <button
                  onClick={toggleMobileServiceAreas}
                  className={`mobile-nav-item flex items-center justify-between w-full px-4 py-3 rounded-lg font-medium transition-all duration-300 ${
                    isServiceAreasActive() || mobileServiceAreasOpen
                      ? 'text-blue-600 bg-gradient-to-r from-green-50 to-blue-50 shadow-sm' 
                      : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50'
                  }`}
                  aria-expanded={mobileServiceAreasOpen}
                  aria-label="Service areas menu"
                >
                  <span className="flex items-center">
                    📍 Service Areas
                    {mobileServiceAreasOpen && <span className="ml-2 text-xs bg-green-100 text-green-700 px-2 py-0.5 rounded-full">All Miami-Dade</span>}
                  </span>
                  <ChevronRight className={`h-4 w-4 transition-transform duration-300 ${
                    mobileServiceAreasOpen ? 'rotate-90' : ''
                  }`} />
                </button>
                {mobileServiceAreasOpen && (
                  <div className="pl-4 space-y-1 max-h-48 overflow-y-auto animate-fade-in-up">
                    {serviceAreas.map((area, index) => (
                      <Link
                        key={index}
                        to={area.path}
                        className="flex items-center px-4 py-2.5 text-sm text-gray-600 hover:text-blue-600 hover:bg-gradient-to-r hover:from-green-50 hover:to-blue-50 rounded-lg transition-all duration-300 group"
                        onClick={closeMobileMenu}
                      >
                        <MapPin className="h-3 w-3 mr-2 text-green-500 group-hover:scale-110 transition-transform" />
                        <div className="flex-1">
                          <div className="flex items-center">
                            <span className="font-medium">{area.name}</span>
                            {area.popular && (
                              <span className="ml-2 text-xs bg-blue-100 text-blue-700 px-2 py-0.5 rounded-full">
                                Popular
                              </span>
                            )}
                          </div>
                          <div className="text-xs text-gray-500">{area.description}</div>
                        </div>
                      </Link>
                    ))}
                  </div>
                )}
              </div>
              
              <Link 
                to="/project-gallery" 
                className={`mobile-nav-item block px-4 py-3 rounded-lg font-medium transition-all duration-300 ${
                  isActive('/project-gallery') 
                    ? 'text-blue-600 bg-gradient-to-r from-blue-50 to-indigo-50 border-l-4 border-blue-600 shadow-sm' 
                    : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50'
                }`}
                onClick={closeMobileMenu}
                aria-current={isActive('/project-gallery') ? 'page' : undefined}
              >
                🏗️ Projects
              </Link>
              <Link 
                to="/blog" 
                className={`mobile-nav-item block px-4 py-3 rounded-lg font-medium transition-all duration-300 ${
                  isActive('/blog') 
                    ? 'text-blue-600 bg-gradient-to-r from-blue-50 to-indigo-50 border-l-4 border-blue-600 shadow-sm' 
                    : 'text-gray-700 hover:text-blue-600 hover:bg-blue-50'
                }`}
                onClick={closeMobileMenu}
                aria-current={isActive('/blog') ? 'page' : undefined}
              >
                📝 Blog
              </Link>
              <a 
                href="#about" 
                className="mobile-nav-item block px-4 py-3 rounded-lg font-medium text-gray-700 hover:text-blue-600 hover:bg-blue-50 transition-all duration-300" 
                onClick={closeMobileMenu}
              >
                ℹ️ About
              </a>
              
              {/* Enhanced Mobile CTA Buttons */}
              <div className="pt-4 space-y-3 border-t border-gray-200">
                <a 
                  href="tel:3055550123"
                  className="flex items-center justify-center w-full bg-gradient-to-r from-blue-600 to-blue-700 text-white py-4 rounded-lg font-semibold hover:from-blue-700 hover:to-blue-800 transition-all duration-300 shadow-lg hover:shadow-xl transform hover:scale-105"
                  onClick={closeMobileMenu}
                >
                  <Phone className="h-4 w-4 mr-2 animate-pulse" />
                  Call (305) 555-0123
                  <span className="ml-2 text-xs bg-green-500 px-2 py-0.5 rounded-full">24/7</span>
                </a>
                <a 
                  href="#contact" 
                  className="flex items-center justify-center w-full border-2 border-blue-600 text-blue-600 py-4 rounded-lg font-semibold hover:bg-blue-600 hover:text-white transition-all duration-300 hover:shadow-lg transform hover:scale-105"
                  onClick={closeMobileMenu}
                >
                  💬 Get Free Consultation
                </a>
              </div>
            </div>
          </div>
        )}
      </nav>

      {/* Main Content */}
      <main className={`transition-all duration-500 ${isScrolled ? 'pt-16' : 'pt-28'}`} id="main-content">
        {children}
      </main>

      {/* Enhanced Scroll to Top Button */}
      {showScrollTop && (
        <button
          onClick={scrollToTop}
          className="fixed bottom-6 right-6 bg-gradient-to-r from-blue-600 to-blue-700 text-white p-3 rounded-full shadow-lg hover:shadow-xl transition-all duration-300 transform hover:scale-110 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 z-40 animate-bounce"
          aria-label="Scroll to top"
        >
          <ArrowUp className="h-5 w-5" />
        </button>
      )}

      {/* Enhanced Chat Widget */}
      {showChatWidget && (
        <div className="fixed bottom-6 left-6 z-40">
          <div className="bg-white rounded-2xl shadow-2xl border border-gray-200 p-4 max-w-sm animate-fade-in-up">
            <div className="flex items-center justify-between mb-3">
              <div className="flex items-center">
                <div className="w-3 h-3 bg-green-500 rounded-full animate-pulse mr-2"></div>
                <span className="font-semibold text-gray-900">Need IT Help?</span>
              </div>
              <button
                onClick={() => setShowChatWidget(false)}
                className="text-gray-400 hover:text-gray-600 transition-colors"
                aria-label="Close chat widget"
              >
                <X className="h-4 w-4" />
              </button>
            </div>
            <p className="text-sm text-gray-600 mb-4">
              Our Miami IT experts are online now. Get instant help with your technology needs!
            </p>
            <div className="flex space-x-2">
              <a
                href="tel:3055550123"
                className="flex-1 bg-blue-600 text-white px-3 py-2 rounded-lg text-sm font-medium hover:bg-blue-700 transition-colors flex items-center justify-center"
              >
                <Phone className="h-3 w-3 mr-1" />
                Call Now
              </a>
              <a
                href="#contact"
                className="flex-1 border border-blue-600 text-blue-600 px-3 py-2 rounded-lg text-sm font-medium hover:bg-blue-50 transition-colors flex items-center justify-center"
                onClick={() => setShowChatWidget(false)}
              >
                <MessageCircle className="h-3 w-3 mr-1" />
                Chat
              </a>
            </div>
          </div>
        </div>
      )}

      {/* Enhanced Footer with Complete Service Area Links */}
      <footer className="bg-gray-900 text-white py-12 relative overflow-hidden">
        <div className="absolute inset-0 bg-gradient-to-br from-gray-900 via-gray-800 to-gray-900"></div>
        <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid md:grid-cols-5 gap-8">
            <div className="md:col-span-2">
              <div className="flex items-center mb-4">
                <Shield className="h-8 w-8 text-blue-400 mr-2" />
                <span className="font-bold text-xl">Managed IT Services Miami</span>
              </div>
              <p className="text-gray-400 mb-6 leading-relaxed">
                Your trusted IT partner in Miami since 2008, providing comprehensive managed IT services to help your business thrive in the digital age.
              </p>
              <div className="flex items-center space-x-4 mb-4">
                <Phone className="h-5 w-5 text-blue-400" />
                <a href="tel:3055550123" className="text-gray-400 hover:text-white transition-colors font-semibold">
                  (305) 555-0123
                </a>
                <span className="text-xs bg-green-600 text-white px-2 py-1 rounded-full animate-pulse">
                  24/7
                </span>
              </div>
              <div className="flex items-center space-x-2">
                <Star className="h-4 w-4 text-yellow-400" />
                <span className="text-sm text-gray-400">4.9/5 • 500+ Happy Clients</span>
              </div>
            </div>
            
            <div>
              <h3 className="font-semibold text-lg mb-4 text-blue-400">Popular Services</h3>
              <ul className="space-y-3 text-gray-400">
                <li><Link to="/services/it-support" className="hover:text-white transition-colors flex items-center group">
                  <span className="mr-2 group-hover:scale-110 transition-transform">🎧</span>
                  24/7 IT Support
                </Link></li>
                <li><Link to="/services/cybersecurity-services" className="hover:text-white transition-colors flex items-center group">
                  <span className="mr-2 group-hover:scale-110 transition-transform">🛡️</span>
                  Cybersecurity
                </Link></li>
                <li><Link to="/services/cloud-solutions" className="hover:text-white transition-colors flex items-center group">
                  <span className="mr-2 group-hover:scale-110 transition-transform">☁️</span>
                  Cloud Solutions
                </Link></li>
                <li><Link to="/services/network-management" className="hover:text-white transition-colors flex items-center group">
                  <span className="mr-2 group-hover:scale-110 transition-transform">🌐</span>
                  Network Management
                </Link></li>
              </ul>
            </div>
            
            <div>
              <h3 className="font-semibold text-lg mb-4 text-green-400">Company</h3>
              <ul className="space-y-3 text-gray-400">
                <li><Link to="/" className="hover:text-white transition-colors">Home</Link></li>
                <li><Link to="/project-gallery" className="hover:text-white transition-colors">Projects</Link></li>
                <li><Link to="/blog" className="hover:text-white transition-colors">Blog</Link></li>
                <li><a href="#contact" className="hover:text-white transition-colors">Contact</a></li>
              </ul>
            </div>
            
            <div>
              <h3 className="font-semibold text-lg mb-4 text-purple-400">All Service Areas</h3>
              <div className="grid grid-cols-1 gap-1 text-gray-400 text-sm max-h-64 overflow-y-auto">
                {serviceAreas.map((area, index) => (
                  <Link 
                    key={index}
                    to={area.path} 
                    className="flex items-center hover:text-white transition-colors group py-1"
                  >
                    <MapPin className="h-3 w-3 mr-2 text-purple-400 group-hover:scale-110 transition-transform flex-shrink-0" />
                    <span className="truncate">{area.name}</span>
                    {area.popular && (
                      <span className="ml-1 text-xs bg-blue-600 text-white px-1 py-0.5 rounded text-[10px] flex-shrink-0">
                        ★
                      </span>
                    )}
                  </Link>
                ))}
              </div>
              <div className="mt-3 pt-3 border-t border-gray-700">
                <Link 
                  to="/miami-it-services/miami-dade-county-it-services" 
                  className="text-blue-400 font-medium hover:text-blue-300 transition-colors flex items-center group text-sm"
                >
                  <MapPin className="h-3 w-3 mr-2 group-hover:scale-110 transition-transform" />
                  Complete Miami-Dade Coverage
                </Link>
              </div>
            </div>
          </div>
          
          <div className="border-t border-gray-800 mt-8 pt-8 text-center text-gray-400">
            <div className="flex flex-col md:flex-row justify-between items-center">
              <p>&copy; 2025 Managed IT Services Miami. All rights reserved.</p>
              <div className="flex space-x-4 mt-4 md:mt-0">
                <a href="#" className="hover:text-white transition-colors text-sm">Privacy Policy</a>
                <a href="#" className="hover:text-white transition-colors text-sm">Terms of Service</a>
              </div>
            </div>
            <p className="mt-4 text-sm">
              Serving Miami businesses with professional managed IT services since 2008. 
              <span className="text-blue-400 font-medium"> Microsoft Certified Partner</span> • 
              <span className="text-green-400 font-medium"> SOC 2 Compliant</span>
            </p>
          </div>
        </div>
      </footer>
    </div>
  );
}